<!DOCTYPE html>
<html lang="en">

<head>
   <meta charset="UTF-8">
   <meta name="viewport" content="width=device-width, initial-scale=1.0">
   <meta http-equiv="X-UA-Compatible" content="ie=edge">
   <title>Document</title>
   <style type="text/css">
      body {
         margin: 30px 0px;
         font-family: Gotham, "Helvetica Neue", Helvetica, Arial, sans-serif;
      }

      h1,
      h2,
      h3,
      h4,
      h5,
      h6,
      p {
         margin: 5px 0;
      }

      h1 {
         font-size: 24px;
      }

      h2 {
         font-size: 18px;
      }

      h3 {
         font-size: 14px;
         color: #3d3d3d;
         font-weight: 200;
      }

      h4 {
         font-size: 14px;
      }

      p {
         font-size: 16px;
      }

      .pl-1 {
         padding-left: 1rem
      }

      .bx-none {
         border-left: none;
         border-right: none;
      }

      .bl-none {
         border-left: none;
      }

      .br-none {
         border-right: none;
      }

      .fake-img {
         width: 100%;
         height: 800px;
         border: 1px solid #3d3d3d;
         text-align: center;
      }

      .title-table {
         background-color: #002859;
         color: #FFFFFF;
      }

      table {
         padding-bottom: 1rem;
      }

      .img-container {
         padding-top: 1rem auto;
      }
   </style>
</head>

<body>
   <table width="100%" border="0" cellspacing="0" cellpadding="0">
      <tbody>
         <tr>
            <td>
            @if($asignacion_solicitudes[0]->sProveedor == "COMTECGLOBAL")
               <img src="{{ asset ("img/logo/comtecglobal_logo.jpeg" ) }}" width="200" height="50">
            @elseif($asignacion_solicitudes[0]->sProveedor == "A&A")
               <img src="{{ asset ("img/logo/Kyocera_New_HP_Logo.jpg" ) }}" width="300" height="34">
               @elseif($asignacion_solicitudes[0]->sProveedor == "DEIRA")
               <img src="{{ asset ("img/logo/737logo_Servicios.png" ) }}" width="300" height="34">
            @else
            @endif
            </td>
            <td>&nbsp;</td>
            <td>

            </td>
         </tr>
      </tbody>
   </table>
   <br>

   <table width="100%" border="0" cellspacing="0" cellpadding="0">
      <tbody>
         <tr>
            <td>
               <h2 align="center">Orden de servicio en terreno y manteniemiento preventivo</h2>
            </td>
         </tr>
      </tbody>
   </table>

   <hr style="margin: 20px 0">
   <h3><strong>Asignación</strong></h3>
   <table width="100%" border="0" cellspacing="0" cellpadding="0">
      <tbody>
         <tr align="center">
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Cliente</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Dirección</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Contacto</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Telefono</h4>
            </td>
         </tr>
         <tr>
            <td>
               <p style="text-transform:uppercase;text-align:center;">
                  <span>{{$asignacion_solicitudes[0]->sCliente ?? ''}}</span>
               </p>
            </td>
            <td><span>
                  <p style="text-transform:uppercase;text-align:center;"></p>
                  {{$asignacion_solicitudes[0]->sDireccion ?? ''}}
               </span></td>
            <td><span>
                  <p style="text-transform:uppercase;text-align:center;"></p>
                  {{$asignacion_solicitudes[0]->nombre_contacto_firma ?? ''}}
               </span></td>
            <td><span>
                  <p style="text-transform:uppercase;text-align:center;"></p>
                  {{$asignacion_solicitudes[0]->sTelefono ?? ''}}
               </span></td>
         </tr>
      </tbody>
   </table>
   <!-- DATOS DEL MODELO -->
   <table width="100%" border="0" cellspacing="0" cellpadding="0">
      <tbody>
         <tr align="center">
         <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Equipo</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Marca</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Modelo</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Serie</h4>
            </td>
         
         </tr>
         <tr>
         <td>
               <p style="text-transform:uppercase;text-align:center;">
                  <span>{{$asignacion_solicitudes[0]->equipos ?? ''}}</span>
               </p>
            </td>
            <td>
               <p style="text-transform:uppercase;text-align:center;">
                  <span>{{$asignacion_solicitudes[0]->Smarca ?? ''}}</span>
               </p>
            </td>
            <td>
               <p style="text-transform:uppercase;text-align:center;">
                  <span>{{$asignacion_solicitudes[0]->sModelo ?? ''}}</span>
               </p>
            </td>
            <td>
               <span>
                  <p style="text-transform:uppercase;text-align:center;">{{$asignacion_solicitudes[0]->sSerie ?? ''}}</p>
               </span>
            </td>

         </tr>
      </tbody>
   </table>
   <!--USB E IP-->
   <table width="100%" border="0" cellspacing="0" cellpadding="0">
      <tbody>
         <tr align="center">
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Cont. B/N</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Cont. Color</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>IP</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>USB</h4>
            </td>
         </tr>
         <tr>
            <td>
               <span>
                  <p style="text-transform:uppercase;text-align:center;">{{$asignacion_solicitudes[0]->contador_bn ?? ''}}</p>
               </span>
            </td>
            <td>
               <span>
                  <p style="text-transform:uppercase;text-align:center;">{{$asignacion_solicitudes[0]->contador_color ?? ''}}</p>
               </span>
            </td>
            <td>
               <span>
                  <p style="text-transform:uppercase;text-align:center;">{{$asignacion_solicitudes[0]->ip ?? ''}}</p>
               </span>
            </td>
            <td>
               <span>
                  <p style="text-transform:uppercase;text-align:center;">{{$asignacion_solicitudes[0]->usb ?? ''}}</p>
               </span>
            </td>
         </tr>
      </tbody>
   </table>
   <!-- DATOS OT-->
   <table width="100%" border="0" cellspacing="0" cellpadding="0">
      <tbody>
         <tr align="center">
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Nº de OT</h4>
            </td>

            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Ciudad</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Region</h4>
            </td>
         </tr>
         <tr>
            <td>
               <p style="text-transform:uppercase;text-align:center;">
                  <span>{{$asignacion_solicitudes[0]->numero_ot ?? ''}}</span>
               </p>
            </td>
            @php
            $date = date_create($asignacion_solicitudes[0]->fecha_check);
            $fecha = date_format($date,"d-m-Y");
            @endphp

            <td>
               <span>
                  <p style="text-transform:uppercase;text-align:center;">{{$asignacion_solicitudes[0]->sComuna ?? ''}}</p>
               </span>
            </td>
            <td>
               <span>
                  <p style="text-transform:uppercase;text-align:center;">{{$asignacion_solicitudes[0]->sRegion ?? ''}}</p>
               </span>
            </td>
         </tr>
      </tbody>
   </table>

   <table width="100%" border="0" cellspacing="0" cellpadding="0">
      <tbody>
         <tr align="center">

            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Fecha de inicio</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Fecha de termino</h4>
            </td>

         </tr>
         <tr>

            <td>
               <span>
                  <p style="text-transform:uppercase;text-align:center;">{{$fecha_inicio}}</p>
               </span>
            </td>

            <td>
               <span>
                  <p style="text-transform:uppercase;text-align:center;">{{$fecha_fin}}</p>
               </span>
            </td>

         </tr>
      </tbody>
   </table>


   <hr style="margin: 10px 0">

   <h3><strong>Reportes del Cliente</strong></h3>
   <table width="100%" border="0" cellpadding="0" cellspacing="0" style="word-wrap: break-word;">
      <tbody>
         <tr align="left">
            <td width="100%" colspan="3" class="title-table" style="border-right: solid 2px #fff; padding-left: 10px;text-transform:uppercase;color:white">
               <h4><strong>Observaciones</strong></h4>
            </td>
         </tr>
         <tr>
            <td height="40" colspan="3">
               <div name="obsercaviones" name="observaciones" style="word-wrap: break-word;">
                  {{$asignacion_solicitudes[0]->descripcion ?? ''}}
               </div>
            </td>
         </tr>
      </tbody>
   </table>

   <hr style="margin: 20px 0">

   <h3><strong>Cambios de piezas y partes sujeto a cobro</strong></h3>
   <!--SOLICITUD ACCESORIOS-->
   <hr style="margin: 10px 0">
      <h3><strong>Motivo: </strong> {{$asignacion_solicitudes[0]->motivo_accesorio}}</h3>

   <h3><strong>Partes Dañanadas</strong></h3>
   <table width="100%" border="0" cellspacing="0" cellpadding="0">
      <tbody>
         <tr align="center">
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Nombre de la pieza</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Numero de parte</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>S/N parte</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Cantidad</h4>
            </td>
         </tr>
         @foreach ($acceDanos as $key => $los_datos)
         <tr>
            <td>
               <p style="text-transform:uppercase;text-align:center;"><span>{{$los_datos->descripcion}}</span></p>
            </td>
            <td>
               <span>
                  <p style="text-transform:uppercase;text-align:center;">{{$los_datos->articulo}}</p>
               </span>
            </td>
            <td>
               <span>
                  <p style="text-transform:uppercase;text-align:center;">{{$los_datos->serie_parte}}</p>
               </span>
            </td>
            <td>
               <span>
                  <p style="text-transform:uppercase;text-align:center;">{{$los_datos->cantidad}}</p>
               </span>
            </td>
         </tr>
      </tbody>
      @endforeach
   </table>

   <h3><strong>Partes Solicitadas</strong></h3>
   <table width="100%" border="0" cellspacing="0" cellpadding="0">
      <tbody>
         <tr align="center">
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Nombre de la pieza</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Numero de parte</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>S/N parte</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Cantidad</h4>
            </td>
         </tr>
         @foreach ($acceSoli as $key => $los_datos)
         <tr>
            <td>
               <p style="text-transform:uppercase;text-align:center;"><span>{{$los_datos->descripcion}}</span></p>
            </td>
            <td><span>
                  <p style="text-transform:uppercase;text-align:center;"></p> {{$los_datos->articulo}}
               </span></td>
            <td><span>
                  <p style="text-transform:uppercase;text-align:center;"></p>{{$los_datos->serie_parte}}
               </span></td>
            <td><span>
                  <p style="text-transform:uppercase;text-align:center;"></p> {{$los_datos->cantidad}}
               </span></td>
         </tr>
      </tbody>
      @endforeach
   </table>

   <h3><strong>Partes Solicitadas Manuales</strong></h3>
   <table width="100%" border="0" cellspacing="0" cellpadding="0">
      <tbody>
         <tr align="center">
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Nombre de la pieza</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Numero de parte</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>S/N parte</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Cantidad</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Observaciones</h4>
            </td>
         </tr>
         @foreach ($acceManu as $key => $los_datos)
         <tr>
            <td>
               <p style="text-transform:uppercase;text-align:center;"><span>{{$los_datos->nombre_parte}}</span></p>
            </td>
            <td><span>
                  <p style="text-transform:uppercase;text-align:center;"></p> {{$los_datos->numero_parte}}
               </span></td>
            <td><span>
                  <p style="text-transform:uppercase;text-align:center;"></p>{{$los_datos->serie_parte}}
               </span></td>
            <td><span>
                  <p style="text-transform:uppercase;text-align:center;"></p> {{$los_datos->cantidad}}
               </span></td>
            <td><span>
                  <p style="text-transform:uppercase;text-align:center;"></p> {{$los_datos->observacion}}
               </span></td>
         </tr>
      </tbody>
      @endforeach
   </table>


   <hr style="margin: 10px 0">

   <h3><strong>Instalacion de accesorios</strong></h3>
   <table width="100%" border="0" cellspacing="0" cellpadding="0">
      <tbody>
         <tr align="center">
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Nombre de la pieza</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Numero de parte</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>S/N parte</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Cantidad</h4>
            </td>
            {{-- <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Observaciones</h4>
            </td> --}}
         </tr>
         						@if(count($instalacion_accesorios) != 0)

         @foreach ($instalacion_accesorios as $key => $los_datos)
												<tr>
													<td>
														{{$los_datos->descripcion}}
													</td>
													<td>
														{{$los_datos->articulo}}
													</td>
													<td>
														{{$los_datos->serie_parte}}
													</td>
													<td>
														{{$los_datos->cantidad}}
													</td>
												</tr>
			@endforeach
         @endif
         {{-- @foreach ($instalacion_accesorios as $key => $los_datos)
         <tr>
             <td>
               <p style="text-transform:uppercase;text-align:center;"><span>{{$los_datos->nombre_parte}}</span></p>
            </td>
            <td><span>
                  <p style="text-transform:uppercase;text-align:center;"></p> {{$los_datos->numero_parte}}
               </span></td>
            <td><span>
                  <p style="text-transform:uppercase;text-align:center;"></p>{{$los_datos->serie_parte}}
               </span></td>
            <td><span>
                  <p style="text-transform:uppercase;text-align:center;"></p> {{$los_datos->cantidad}}
               </span></td>
            <td><span>
                  <p style="text-transform:uppercase;text-align:center;"></p> {{$los_datos->observacion}}
               </span></td> 
         </tr>
      </tbody>
      @endforeach --}}
   </table>
   <hr style="margin: 10px 0">

   <!--<h3><strong>Nº de serie, componentes sustituidos</strong></h3>

   <div class="title-table" style="padding: 2px 20px; text-align:center;border-bottom: solid 2px #fff;">
      <h4 style="padding-top:6px;">DV - UN Revelado(s)</h4>
   </div>
   <table width="100%" border="0" cellspacing="0" cellpadding="0">
      <tbody>
         <tr align="center">
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>ID color</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Nombre de la pieza</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Número de parte</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>S/N parte</h4>
            </td>
            <td class="title-table">
               <h4>Cantidad</h4>
            </td>
         </tr>
         @foreach ($tipo_equipamientos_dvRevelado as $key => $los_datos)
         <tr class="2eliminar{{$key+1}}">
            <td class="pl-1">
               <span>
                  <p style="text-transform:uppercase;">{{$los_datos->tipo}}</p>
               </span>
            </td>
            <td>
               <span>
                  <p style="text-transform:uppercase;text-align:center;">{{$los_datos->serie}}</p>
               </span>
            </td>
            <td>
               <span>
                  <p style="text-transform:uppercase;text-align:center;">{{$los_datos->descripcion}}</p>
               </span>
            </td>
            <td>
               <span>
                  <p style="text-transform:uppercase;text-align:center;">{{$los_datos->numero_parte}}</p>
               </span>
            </td>
            <td>
               <span>
                  <p style="text-transform:uppercase;text-align:center;">{{$los_datos->cantidad}}</p>
               </span>
            </td>
         </tr>
         @endforeach
      </tbody>
   </table>

   <div class="title-table" style="padding: 2px 20px; text-align:center;border-bottom: solid 2px #fff;">
      <h4>DDK - UN Cilindro(s)</h4>
   </div>
   <table width="100%" border="0" cellspacing="0" cellpadding="0">
      <tbody>
         <tr align="center">
            <td class="title-table"></td>
            <td class="title-table"></td>
            <td class="title-table"></td>
            <td class="title-table" style="border-right: solid 2px #fff"></td>
         </tr>
         <tr align="center">
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>ID color</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Nombre de la pieza</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Número de parte</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>S/N parte</h4>
            </td>
            <td class="title-table">
               <h4>Cantidad</h4>
            </td>
         </tr>
         @foreach ($tipo_equipamientos_dkCilindro as $key => $los_datos)
         <tr class="2eliminar{{$key+1}}">
            <td class="pl-1">
               <span>
                  <p style="text-transform:uppercase;">{{$los_datos->tipo}}</p>
               </span>
            </td>
            <td>
               <span>
                  <p style="text-transform:uppercase;text-align:center;">{{$los_datos->serie}}</p>
               </span>
            </td>
            <td>
               <span>
                  <p style="text-transform:uppercase;text-align:center;">{{$los_datos->descripcion}}</p>
               </span>
            </td>
            <td>
               <span>
                  <p style="text-transform:uppercase;text-align:center;">{{$los_datos->numero_parte}}</p>
               </span>
            </td>
            <td>
               <span>
                  <p style="text-transform:uppercase;text-align:center;">{{$los_datos->cantidad}}</p>
               </span>
            </td>
         </tr>
      </tbody>
      @endforeach
   </table>

   <div class="title-table" style="padding: 2px 20px; text-align:center;border-bottom: solid 2px #fff;">
      <h4>Detalle del equipamiento</h4>
   </div>
   <table width="100%" border="0" cellspacing="0" cellpadding="0">
      <tbody>
         <tr align="center">
            <td class="title-table"></td>
            <td class="title-table"></td>
            <td class="title-table"></td>
            <td class="title-table" style="border-right: solid 2px #fff"></td>
         </tr>
         <tr align="center">
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>IP color</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Nombre de la pieza</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>Número de parte</h4>
            </td>
            <td class="title-table" style="border-right: solid 2px #fff">
               <h4>S/N parte</h4>
            </td>
            <td class="title-table">
               <h4>Cantidad</h4>
            </td>
         </tr>
         @foreach ($tipo_equipamientos_detalleEquipamiento as $key => $los_datos)
         <tr class="2eliminar{{$key+1}}">
            <td class="pl-1">
               <span>
                  <p style="text-transform:uppercase;">{{$los_datos->tipo}}</p>
               </span>
            </td>
            <td>
               <span>
                  <p style="text-transform:uppercase;text-align:center;">{{$los_datos->serie}}</p>
               </span>
            </td>
            <td>
               <span>
                  <p style="text-transform:uppercase;text-align:center;">{{$los_datos->descripcion}}</p>
               </span>
            </td>
            <td>
               <span>
                  <p style="text-transform:uppercase;text-align:center;">{{$los_datos->numero_parte}}</p>
               </span>
            </td>
            <td>
               <span>
                  <p style="text-transform:uppercase;text-align:center;">{{$los_datos->cantidad}}</p>
               </span>
            </td>
         </tr>
         @endforeach
   </table>
   <hr style="margin: 10px 0">-->

   <h3><strong>Piezas solicitadas validadas por </strong></h3>
   <table width="100%" border="0" cellpadding="0" cellspacing="0" style="word-wrap: break-word;">
      <tbody>
         <tr align="left">
            <td width="100%" colspan="3" class="title-table" style="border-right: solid 2px #fff; padding-left: 10px;text-transform:uppercase;">
               <h4><strong>Validador</strong></h4>
            </td>
         </tr>
         <tr>
            <td height="40" colspan="3">
               <div name="obsercaviones" name="observaciones" style="word-wrap: break-word;font-family:'Roboto', Sans-Serif;text-transform:uppercase;">
                  {{ $asignacion_solicitudes[0]->validador ?? 'sin validador'}}
               </div>
            </td>
         </tr>
      </tbody>
   </table>
   <hr style="margin: 10px 0">

   <h3><strong>Reportes del Tecnico</strong></h3>
   <table width="100%" border="0" cellpadding="0" cellspacing="0" style="word-wrap: break-word;">
      <tbody>
         <tr align="left">
            <td width="100%" colspan="3" class="title-table" style="border-right: solid 2px #fff; padding-left: 10px;text-transform:uppercase;">
               <h4><strong>Observaciones</strong></h4>
            </td>
         </tr>
         <tr>
            <td height="40" colspan="3">
               <div name="obsercaviones" name="observaciones" style="word-wrap: break-word;font-family:'Roboto', Sans-Serif;text-transform:uppercase;">
                  {{ $asignacion_solicitudes[0]->observaciones ?? 'Sin observacion'}}
               </div>
            </td>
         </tr>
      </tbody>
   </table>
   <!--,,,,,-->

   <hr style="margin: 10px 0">

   <table width="100%" border="0" cellpadding="0" cellspacing="0">
      <tbody>
         <tr align="center">
            <td width="33%" colspan="2" class="title-table" style="border-right: solid 2px #fff">
               <h4><strong>Datos del Técnico</strong></h4>
            </td>
            <td width="33%" colspan="2" class="title-table" style="border-right: solid 2px #fff">
               <h4><strong>Datos del Contacto</strong></h4>
            </td>
            <td width="33%" colspan="2" class="title-table">
               <h4><strong>Correo del Contacto</strong></h4>
            </td>
         </tr>
         <tr>
            <td height="40" colspan="2">
               <span>
                  <p>{{ $datosTrabajador[0]->nombre_uno ?? ''}} {{ $datosTrabajador[0]->apellido_uno ?? ''}}</p>
               </span>
            </td>
            <td height="40" colspan="2">
               <span>
                  <p>{{ $asignacion_solicitudes[0]->sContacto ?? ''}}</p>
               </span>
            </td>
            <td height="40" colspan="2">
               <span>
                  <p>{{ $asignacion_solicitudes[0]->correo_contacto ?? ''}}</p>
               </span>
            </td>
         </tr>
      </tbody>
   </table>


   <table width="100%" border="0" cellpadding="0" cellspacing="0">
      <tbody>
         <tr>
            <td width="50%" colspan="3">
               <h3><strong>Firma Técnico</strong></h3>
            </td>
            <td width="50%" colspan="3">
               <h3><strong>Firma Contacto</strong></h3>
            </td>
         </tr>
         <tr>
            <td height="40" colspan="3" style="text-align: center;" align="center">
            @if(count($firmatrabajador)!= 0)
               <img src="{{ asset ("fotos/".$firmatrabajador[0]->url_firma)}}" alt="" width="100" height="100">
               @else
               @endif
            </td>
            <td height="40" colspan="3" style="text-align: center;" align="center">
               @if($asignacion_solicitudes[0]->firma_contacto === "si" && $asignacion_solicitudes[0]->url_firma != "")
               <img src="{{ asset ("fotos/".$asignacion_solicitudes[0]->url_firma)}}" alt="" width="100" height="100">
               @else
               <input type="checkbox" class="custom-control-input" checked id="no_firma_cliente" name="no_firma_cliente">Cliente se niega a firmar
               @endif
            </td>
         </tr>
      </tbody>
   </table>

   <table width="100%" border="0" cellspacing="0" cellpadding="0" style="margin-top: 20px">
      <tbody>
         <tr>
            <td style="text-align: center;">

               <img src="{{ asset ("img/logo/A&A-logo.png" ) }}" alt="" width="100" height="100" />
            </td>
         </tr>
      </tbody>
   </table>

   {{-- Imágenes --}}
   <table width="100%" border="0" cellpadding="0" cellspacing="0" style="margin-top: 30px">
      <tbody>
         <tr>
            <td colspan="3" class="title-table" style="border-right: solid 2px #fff; padding-left: 10px">
               <h4><strong>Fotografía de la página de estado</strong></h4>
            </td>
         </tr>
         <tr>
            <td class="img-container" style="width: 100%;">
               @if(count($fotos_servicios_cheks) > 0)
               @php
                  //$extencion = explode(".",$fotos_servicios_cheks[0]->url);
                  //if($extencion[1] == "jpeg" || $extencion[1] == "jpg"){
                     //$a = imagecreatefromjpeg(("/var/www/html/aya/rendicion/fotos/".$fotos_servicios_cheks[0]->url ?? ''));
                     //$calidad = 50;
                     //$nuevo = imagejpeg($a,("/var/www/html/aya/rendicion/fotos/".$fotos_servicios_cheks[0]->url), $calidad);
                     //}else{
                        //$a = imagecreatefrompng(("/var/www/html/aya/rendicion/fotos/".$fotos_servicios_cheks[0]->url ?? ''));
                        //$calidad = 50;
                        //$nuevo = imagepng($a,("/var/www/html/aya/rendicion/fotos/".$fotos_servicios_cheks[0]->url), $calidad);
                        //}
               @endphp
               <div class="fake-img"><img src="{{ asset ("fotos/".$fotos_servicios_cheks[0]->url) ?? ''}}" alt="cajas" width="700" height="700"></div>
               @endif
            </td>
         </tr>
      </tbody>
   </table>

   <table width="100%" border="0" cellpadding="0" cellspacing="0" style="margin-top: 30px">
      <tbody>
         <tr>
            <td class="img-container" colspan="3" class="title-table" style="border-right: solid 2px #fff; padding-left: 10px">
               <h4><strong>Fotografía del panel de la máquina</strong></h4>
            </td>
         </tr>
         <tr>
            <td class="img-container" style="width: 100%;">
               @if(count($fotos_servicios_cheks) > 1)
               @php
               //$extencion = explode(".",$fotos_servicios_cheks[1]->url);
               //   if($extencion[1] == "jpeg" || $extencion[1] == "jpg"){
               //      $a = imagecreatefromjpeg(("/var/www/html/aya/rendicion/fotos/".$fotos_servicios_cheks[1]->url ?? ''));
               //      $calidad = 50;
               //      $nuevo = imagejpeg($a,("/var/www/html/aya/rendicion/fotos/".$fotos_servicios_cheks[1]->url), $calidad);
               //   }else{
               //      $a = imagecreatefrompng(("/var/www/html/aya/rendicion/fotos/".$fotos_servicios_cheks[1]->url ?? ''));
               //      $calidad = 50;
               //      $nuevo = imagepng($a,("/var/www/html/aya/rendicion/fotos/".$fotos_servicios_cheks[1]->url), $calidad);
               //   }
               @endphp
               <div class="fake-img"><img src="{{ asset ("fotos/".$fotos_servicios_cheks[1]->url) ?? ''}}" alt="cajas" width="700" height="700"></div>
               @endif
            </td>
      </tbody>
   </table>

   <table width="100%" border="0" cellpadding="0" cellspacing="0" style="margin-top: 30px">
      <tbody>
         <tr>
            <td class="img-container" colspan="3" class="title-table" style="border-right: solid 2px #fff; padding-left: 10px ">
               <h4><strong>Fotografía a 2 metros del equipo</strong></h4>
            </td>
         </tr>
         <tr>
            <td class="img-container" style="width: 100%;">
               @if(count($fotos_servicios_cheks) > 2)
               @php
               //$extencion = explode(".",$fotos_servicios_cheks[2]->url);
               //   if($extencion[1] == "jpeg" || $extencion[1] == "jpg"){
               //      $a = imagecreatefromjpeg(("/var/www/html/aya/rendicion/fotos/".$fotos_servicios_cheks[2]->url ?? ''));
               //      $calidad = 50;
               //      $nuevo = imagejpeg($a,("/var/www/html/aya/rendicion/fotos/".$fotos_servicios_cheks[2]->url), $calidad);
               //   }else{
               //      $a = imagecreatefrompng(("/var/www/html/aya/rendicion/fotos/".$fotos_servicios_cheks[2]->url ?? ''));
               //      $calidad = 50;
               //      $nuevo = imagepng($a,("/var/www/html/aya/rendicion/fotos/".$fotos_servicios_cheks[2]->url), $calidad);
               //   }
               @endphp
               <div class="fake-img"><img src="{{ asset ("fotos/".$fotos_servicios_cheks[2]->url) ?? ''}}" alt="cajas" width="700" height="700"></div>
               @endif
            </td>
         </tr>
      </tbody>
   </table>
   <table width="100%" border="0" cellpadding="0" cellspacing="0" style="margin-top: 30px">
      <tbody>
         <tr>
            <td colspan="3" class="title-table" style="border-right: solid 2px #fff; padding-left: 10px">
               <h4><strong>Fotos adicionales</strong></h4>
            </td>
         </tr>
         @for($i = 3; $i < 13; $i++)
         @if(count($fotos_servicios_cheks)> $i)
               @php
               //$extencion = explode(".",$fotos_servicios_cheks[$i]->url);
               //   if($extencion[1] == "jpeg" || $extencion[1] == "jpg"){
               //      $a = imagecreatefromjpeg(("/var/www/html/aya/rendicion/fotos/".$fotos_servicios_cheks[$i]->url ?? ''));
               //      $calidad = 50;
               //      $nuevo = imagejpeg($a,("/var/www/html/aya/rendicion/fotos/".$fotos_servicios_cheks[$i]->url), $calidad);
               //   }else{
               //      $a = imagecreatefrompng(("/var/www/html/aya/rendicion/fotos/".$fotos_servicios_cheks[$i]->url ?? ''));
               //      $calidad = 50;
               //      $nuevo = imagepng($a,("/var/www/html/aya/rendicion/fotos/".$fotos_servicios_cheks[$i]->url), $calidad);
               //   }
               @endphp
            <tr>
               <td class="img-container" height="" colspan="3" style="padding-top: 0px; text-align: center">

                  <img src="{{ asset ("fotos/".$fotos_servicios_cheks[$i]->url) ?? ''}}"" alt=" cajas" width="700" height="700">
               </td>
            </tr>
         @endif
         @endfor
      </tbody>
   </table>

   <table width="100%" border="0" cellpadding="0" cellspacing="0" style="margin-top: 30px">
      <tbody>
         <tr>
            <td colspan="3" class="title-table" style="border-right: solid 2px #fff; padding-left: 10px">
               <h4><strong>Fotografía de garantia</strong></h4>
            </td>
         </tr>
         @if(!empty($fotos))
         @foreach ($fotos as $los_datos)
         <tr>
            <td height="" colspan="3" style="padding-top: 0px; text-align: center">
               <img src="{{ asset ("fotos/".$los_datos->url) ?? ''}}" alt="cajas" width="700" height="700">
            </td>
         </tr>
         @endforeach
         @endif
      </tbody>
   </table>
</body>

</html>